@@ -1,8 +1,10 @@
 # -*- coding: utf-8 -*-
-import sys,pdb
+import sys
 import unittest
 
+
 class Runner:
+
     def __init__(self, test_cases):
         self.suite = unittest.TestSuite()
         for case in test_cases:
